==> nextcloud-23.0.3.tgz: nextcloud/apps/password_policy/l10n/sl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Geslo je preteklo. Uporabite način za obnovitev pozabljenega gesla.",
    "Password must not have been used recently before." : "Geslo ne sme biti uporabljeno pred kratkim.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Izbrano geslo je med 1 000 000 najpogostejših gesel. Potrudite se, da bo enkratno.",
    "Password is present in compromised password list. Please choose a different password." : "Geslo je zavedeno na seznamu ogroženih gesel. Izberite drugo geslo.",
    "Password needs to be at least %s characters long." : "Geslo mora vsebovati najmanj %s znakov.",
    "Password needs to contain at least one numeric character." : "Geslo mora vsebovati vsaj en številski znak.",
    "Password needs to contain at least one special character." : "Geslo mora vsebovati vsaj en poseben znak.",
    "Password needs to contain at least one lower and one upper case character." : "Geslo mora vsebovati vsaj eno malo in eno veliko tiskano črko.",
    "Password policy" : "Določila gesel",
    "Allows admins to configure a password policy" : "Omogoča skrbnikom nastavljanje pravil uporabe gesel",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Dovoli skrbniku določiti določene predpogoje za gesla, na primer vsiljeno dolžino",
    "Saved" : "Shranjeno",
    "Minimum password length" : "Najmanjša dolžina gesla",
    "User password history" : "Uporabniška zgodovina gesel",
    "Number of days until user password expires" : "Število dni do preteka uporabniškega gesla",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Število poskusov prijave, preden se dostop do uporabniškega računa zaklene (0 pomeni brez omejitve).",
    "Forbid common passwords" : "Prepreči splošna gesla",
    "Enforce upper and lower case characters" : "Zahtevaj velike in male črkovne znake",
    "Enforce numeric characters" : "Zahtevaj številske znake",
    "Enforce special characters" : "Zahtevaj posebne znake",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Preveri kakovost gesla s seznamom neustreznih gesel na haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Ta možnost ustvari nadzorno kodo uporabljenega gesla in pošlje prvih 5 znakov na naslov haveibeenpwned.com, v povratnici pa pridobi seznam vseh podobnih kod. Preveri tudi, ali je nadzorna vsota gesla skladna z geslom, uporabljenim za Nextcloud.",
    "Unknown error" : "Neznana napaka",
    "Minimal length has to be a non negative number" : "Najmanjša dolžina mora biti ne-negativna vrednost.",
    "History size has to be a non negative number" : "Velikost zgodovine mora biti ne-negativna vrednost.",
    "Expiration days have to be a non negative number" : "Število dni do pretaka mora biti ne-negativna vrednost.",
    "Maximum login attempts have to be a non negative number" : "Največje število poskusov prijave mora biti ne-negativna vrednost.",
    "Password needs to be at least %s characters long" : "Geslo mora vsebovati najmanj %s znakov"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-24.0.11p0.tgz: nextcloud/apps/password_policy/l10n/sl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Geslo je preteklo. Uporabite način za obnovitev pozabljenega gesla.",
    "Password must not have been used recently before." : "Geslo ne sme biti uporabljeno pred kratkim.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Izbrano geslo je med 1 000 000 najpogostejših gesel. Potrudite se, da bo enkratno.",
    "Password is present in compromised password list. Please choose a different password." : "Geslo je zavedeno na seznamu ogroženih gesel. Izberite drugo geslo.",
    "Password needs to be at least %s characters long." : "Geslo mora vsebovati najmanj %s znakov.",
    "Password needs to contain at least one numeric character." : "Geslo mora vsebovati vsaj en številski znak.",
    "Password needs to contain at least one special character." : "Geslo mora vsebovati vsaj en poseben znak.",
    "Password needs to contain at least one lower and one upper case character." : "Geslo mora vsebovati vsaj eno malo in eno veliko tiskano črko.",
    "Password policy" : "Določila gesel",
    "Allows admins to configure a password policy" : "Omogoča skrbnikom nastavljanje pravil uporabe gesel",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Dovoli skrbniku določiti določene predpogoje za gesla, na primer vsiljeno dolžino",
    "Minimum password length" : "Najmanjša dolžina gesla",
    "User password history" : "Uporabniška zgodovina gesel",
    "Number of days until user password expires" : "Število dni do preteka uporabniškega gesla",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Število poskusov prijave, preden se dostop do uporabniškega računa zaklene (0 pomeni brez omejitve).",
    "Forbid common passwords" : "Prepreči splošna gesla",
    "Enforce upper and lower case characters" : "Zahtevaj velike in male črkovne znake",
    "Enforce numeric characters" : "Zahtevaj številske znake",
    "Enforce special characters" : "Zahtevaj posebne znake",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Preveri kakovost gesla s seznamom neustreznih gesel na haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Ta možnost ustvari nadzorno kodo uporabljenega gesla in pošlje prvih 5 znakov na naslov haveibeenpwned.com, v povratnici pa pridobi seznam vseh podobnih kod. Preveri tudi, ali je nadzorna vsota gesla skladna z geslom, uporabljenim za Nextcloud.",
    "Unknown error" : "Neznana napaka",
    "Minimal length has to be a non negative number" : "Najmanjša dolžina mora biti ne-negativna vrednost.",
    "History size has to be a non negative number" : "Velikost zgodovine mora biti ne-negativna vrednost.",
    "Expiration days have to be a non negative number" : "Število dni do pretaka mora biti ne-negativna vrednost.",
    "Maximum login attempts have to be a non negative number" : "Največje število poskusov prijave mora biti ne-negativna vrednost.",
    "Settings saved" : "Nastavitve so shranjene",
    "Saved" : "Shranjeno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
